### 0.1.4 (2021-06-08)

- Added basic functionality for GoogleSheets

### 0.1.3 (2021-06-07)

- Wrappers now will connect by default, simplifies the initializing of the classes

### 0.1.2 (2021-05-26)

- Cleaned up commenting and started with preliminary tests

### 0.1.0 (2021-05-26)

- BETA version
- Connect to various Google APIs
- First build
